"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.interpolateStyles = void 0;
const remotion_1 = require("remotion");
const utils_1 = require("./utils");
const interpolatedPropertyPart = ({ inputValue, inputRange, initialStylePropertyPart, finalStylePropertyPart, initialStyleProperty, finalStyleProperty, options, }) => {
    var _a;
    if (finalStylePropertyPart === undefined) {
        throw new TypeError(`The start and end values must be of the same type. Start value: ${initialStyleProperty}, end value: ${finalStyleProperty}`);
    }
    if (initialStylePropertyPart.color) {
        if (!finalStylePropertyPart.color) {
            throw new TypeError(`The start and end values must be of the same type. Start value: ${initialStyleProperty}, end value: ${finalStyleProperty}`);
        }
        const interpolatedColor = (0, remotion_1.interpolateColors)(inputValue, inputRange, [
            initialStylePropertyPart.color,
            finalStylePropertyPart.color,
        ]);
        return `${interpolatedColor}`;
    }
    if (initialStylePropertyPart.function) {
        if (!(finalStylePropertyPart === null || finalStylePropertyPart === void 0 ? void 0 : finalStylePropertyPart.function) ||
            initialStylePropertyPart.function.name !==
                ((_a = finalStylePropertyPart.function) === null || _a === void 0 ? void 0 : _a.name)) {
            throw new TypeError(`The start and end values must be of the same type. Start value: ${initialStyleProperty}, end value: ${finalStyleProperty}`);
        }
        const endValuePartFunction = finalStylePropertyPart.function;
        const endValuePartFunctionArgs = endValuePartFunction.values || [];
        const interpolatedFunctionArgs = initialStylePropertyPart.function.values.reduce((acc, startValuePartFunctionArg, index) => {
            const endValuePartFunctionArg = endValuePartFunctionArgs[index];
            const interpolatedArg = interpolatedPropertyPart({
                inputValue,
                inputRange,
                initialStylePropertyPart: startValuePartFunctionArg,
                finalStylePropertyPart: endValuePartFunctionArg,
                initialStyleProperty,
                finalStyleProperty,
                options,
            });
            return `${acc}, ${interpolatedArg}`;
        }, '');
        return `${initialStylePropertyPart.function.name}(${interpolatedFunctionArgs.slice(2)})`;
    }
    if (typeof initialStylePropertyPart.number === 'undefined') {
        if (initialStylePropertyPart.unit !== finalStylePropertyPart.unit) {
            throw new TypeError(`Non-animatable values cannot be interpolated. Start value: ${initialStyleProperty}, end value: ${finalStyleProperty}`);
        }
        return `${initialStylePropertyPart.unit}`;
    }
    if (initialStylePropertyPart.unit !== finalStylePropertyPart.unit &&
        initialStylePropertyPart.number !== 0 &&
        finalStylePropertyPart.number !== 0) {
        throw new TypeError(`The units of the start and end values must match. Start value: ${initialStyleProperty}, end value: ${finalStyleProperty}`);
    }
    const startNumber = initialStylePropertyPart.number;
    const endNumber = finalStylePropertyPart.number || 0;
    const interpolatedNumber = (0, remotion_1.interpolate)(inputValue, inputRange, [startNumber, endNumber], options);
    const interpolatedUnit = initialStylePropertyPart.unit || finalStylePropertyPart.unit || '';
    if (!interpolatedUnit) {
        return interpolatedNumber;
    }
    return `${interpolatedNumber}${interpolatedUnit}`;
};
const interpolateProperty = ({ inputValue, inputRange, initialStyleProperty, finalStyleProperty, options, }) => {
    if (typeof initialStyleProperty !== typeof finalStyleProperty &&
        initialStyleProperty !== 0 &&
        finalStyleProperty !== 0) {
        throw new TypeError(`The start and end values must be of the same type. Start value: ${initialStyleProperty}, end value: ${finalStyleProperty}`);
    }
    const initialStylePropertyParts = (0, utils_1.breakDownValueIntoUnitNumberAndFunctions)(initialStyleProperty);
    const finalStylePropertyParts = (0, utils_1.breakDownValueIntoUnitNumberAndFunctions)(finalStyleProperty);
    if (initialStylePropertyParts.length !== finalStylePropertyParts.length) {
        throw new TypeError(`The start and end values must have the same structure. Start value: ${initialStyleProperty}, end value: ${finalStyleProperty}`);
    }
    const interpolatedValue = initialStylePropertyParts.reduce((acc, initialStylePropertyPart, index) => {
        return `${acc} ${interpolatedPropertyPart({
            inputValue,
            inputRange,
            initialStylePropertyPart,
            finalStylePropertyPart: finalStylePropertyParts[index],
            initialStyleProperty,
            finalStyleProperty,
            options,
        })}`;
    }, '');
    return interpolatedValue.slice(1);
};
const interpolateStylesFunction = ({ inputValue, inputRange, initialStyle, finalStyle, options, }) => {
    const [startingValue, endingValue] = inputRange;
    return Object.keys(initialStyle).reduce((acc, key) => {
        const value = finalStyle[key];
        if (value === undefined || value === null) {
            return {
                ...acc,
                [key]: initialStyle[key],
            };
        }
        const finalStyleValue = interpolateProperty({
            inputValue,
            inputRange: [startingValue, endingValue],
            initialStyleProperty: initialStyle[key],
            finalStyleProperty: finalStyle[key],
            options,
        });
        // Avoid number to be a string
        if (!isNaN(Number(finalStyleValue))) {
            return {
                ...acc,
                [key]: Number(finalStyleValue),
            };
        }
        return {
            ...acc,
            [key]: finalStyleValue,
        };
    }, {});
};
function checkInputRange(arr) {
    if (arr.length < 2) {
        throw new Error('inputRange must have at least 2 elements');
    }
    for (let index = 0; index < arr.length; index++) {
        if (typeof arr[index] !== 'number') {
            throw new Error(`inputRange must contain only numbers`);
        }
        if (arr[index] === -Infinity || arr[index] === Infinity) {
            throw new Error(`inputRange must contain only finite numbers, but got [${arr.join(',')}]`);
        }
        if (index > 0 && !(arr[index] > arr[index - 1])) {
            throw new Error(`inputRange must be strictly monotonically non-decreasing but got [${arr.join(',')}]`);
        }
    }
}
function checkStylesRange(arr) {
    if (arr.length < 2) {
        throw new Error('outputStyles must have at least 2 elements');
    }
    for (const index in arr) {
        if (typeof arr[index] !== 'object') {
            throw new Error('outputStyles must contain only objects');
        }
    }
}
/*
 * @description A function that interpolates between two styles based on an input range.
 * @see [Documentation](https://remotion.dev/docs/animation-utils/interpolate-styles)
 */
const interpolateStyles = (input, inputRange, outputStylesRange, options) => {
    var _a, _b, _c;
    if (typeof input === 'undefined') {
        throw new Error('input can not be undefined');
    }
    if (typeof inputRange === 'undefined') {
        throw new Error('inputRange can not be undefined');
    }
    if (typeof outputStylesRange === 'undefined') {
        throw new Error('outputRange can not be undefined');
    }
    if (inputRange.length !== outputStylesRange.length) {
        throw new Error('inputRange (' +
            inputRange.length +
            ') and outputStylesRange (' +
            outputStylesRange.length +
            ') must have the same length');
    }
    checkInputRange(inputRange);
    checkStylesRange(outputStylesRange);
    let startIndex = inputRange.findIndex((step) => input < step) - 1;
    if (startIndex === -1) {
        startIndex = 0;
    }
    if (startIndex === -2) {
        startIndex = inputRange.length - 2;
    }
    const endIndex = startIndex + 1;
    const startingValue = inputRange[startIndex];
    const endingValue = inputRange[endIndex];
    const initialStyle = outputStylesRange[startIndex];
    const finalStyle = outputStylesRange[endIndex];
    const easing = (_a = options === null || options === void 0 ? void 0 : options.easing) !== null && _a !== void 0 ? _a : ((num) => num);
    const extrapolateLeft = (_b = options === null || options === void 0 ? void 0 : options.extrapolateLeft) !== null && _b !== void 0 ? _b : 'extend';
    const extrapolateRight = (_c = options === null || options === void 0 ? void 0 : options.extrapolateRight) !== null && _c !== void 0 ? _c : 'extend';
    return interpolateStylesFunction({
        inputValue: input,
        inputRange: [startingValue, endingValue],
        initialStyle,
        finalStyle,
        options: {
            easing,
            extrapolateLeft,
            extrapolateRight,
        },
    });
};
exports.interpolateStyles = interpolateStyles;
